@@ -3,8 +3,9 @@ __author__ = 'ikibalin'
 __version__ = "2020_08_19"
 import os
 import os.path
+from warnings import warn
 import numpy
-from typing import NoReturn
+from typing import NoReturn, List
 import scipy
 import scipy.optimize
 
@@ -113,7 +114,8 @@ class RhoChi(GlobalN):
             n_res += n
         return chi_sq_res, n_res
 
-    def refine(self, disp: bool = False, optimization_method: str = "BFGS"):
+    def refine(self, optimization_method: str = "BFGS", disp: bool = False,
+               d_info: dict = None):
         """
         Minimization procedure.
 
@@ -123,6 +125,13 @@ class RhoChi(GlobalN):
             - "simplex"
             - "basinhopping"
         """
+
+        if d_info is not None:
+            d_info_keys = d_info.keys()
+            if "stop" not in d_info_keys:
+                d_info["stop"] = False
+            d_info["print"] = "Refinement is running."
+
         flag = True
 
         # self.remove_internal_objs
@@ -168,7 +177,8 @@ class RhoChi(GlobalN):
             # simplex
             res = scipy.optimize.minimize(
                 tempfunc, param_0, method='Nelder-Mead',
-                callback=lambda x: self._f_callback(disp, coeff_norm, x),
+                callback=lambda x: self._f_callback(
+                    disp, coeff_norm, x, param_name=l_var_name, d_info=d_info),
                 options={"fatol": 0.01*n})
 
             m_error, dist_hh = error_estimation_simplex(
@@ -179,9 +189,9 @@ class RhoChi(GlobalN):
                 # slightly change definition, instead of (n-k) here is n
                 error = (abs(m_error[i, i])*1./n)**0.5
                 if m_error[i, i] < 0.:
-                    raise UserWarning("Negative diagonal elements of Hessian")
+                    warn("Negative diagonal elements of Hessian.", UserWarning)
                 if val_2 > error:
-                    raise UserWarning("Minimum is not found")
+                    warn("Minimum is not found.", UserWarning)
 
                 l_sigma.append(max(error, val_2))
 
@@ -196,7 +206,8 @@ class RhoChi(GlobalN):
             # BFGS
             res = scipy.optimize.minimize(
                 tempfunc, param_0, method='BFGS',
-                callback=lambda x: self._f_callback(disp, coeff_norm, x),
+                callback=lambda x: self._f_callback(
+                    disp, coeff_norm, x, param_name=l_var_name, d_info=d_info),
                 options={"disp": disp})
 
             _dict_out = {"flag": flag, "res": res}
@@ -215,7 +226,9 @@ class RhoChi(GlobalN):
 
         return _dict_out
 
-    def _f_callback(self, *arg):
+    def _f_callback(self, *arg, param_name: List[tuple] = None,
+                    d_info: dict = None) -> bool:
+        flag_out = False
         disp = arg[0]
         if disp:
             coeff_norm = arg[1]
@@ -224,6 +237,19 @@ class RhoChi(GlobalN):
                                for _1, _2 in zip(res_x, coeff_norm)])
             print(ls_out)
 
+        if d_info is not None:
+            coeff_norm = arg[1]
+            l_param = arg[2]
+            if param_name is not None:
+                ls_out = [f"{name[-1][0]:}: {coeff*param: 10.5f}" for name,
+                          param, coeff in zip(param_name, l_param, coeff_norm)]
+            else:
+                ls_out = [f"{coeff*param: 10.5f}" for param, coeff in zip(
+                    l_param, coeff_norm)]
+            d_info["print"] = "Best solution:\n\n"+"\n".join(ls_out)
+            flag_out = d_info["stop"]
+        return flag_out
+
     def save_to_file(self, f_name):
         """Save to file."""
         self.file_input = f_name
